==> pymetrick-0.41.zip: pymetrick-0.41/setup.py <==
from setuptools import setup

def readme():
    with open('README.md') as f:
        return f.read()


setup(name='pymetrick',
      version='0.41',
      description='Lightweight web framework',
      long_description='lightweight web framework to ecommerce and management',
      classifiers=[
              'Development Status :: 5 - Production/Stable',
              'License :: OSI Approved :: GNU Lesser General Public License v2 or later (LGPLv2+)',
              'Operating System :: OS Independent',
              'Programming Language :: Python :: 2.7',
              'Environment :: Web Environment',
              'Topic :: Internet :: WWW/HTTP :: WSGI :: Application',

            ],      
      url='http://www.pymetrick.org',
      author='Fco. Javier Tamarit V',
      author_email='javtamvi@gmail.com',
      license='GNU/GPLv2',
      packages=['pymetrick'],
      install_requires=[
          'hashlib','hmac','codecs','urllib','urllib2','itertools','decimal','random','base64','struct','smtplib','imaplib','mysql.connector','mysql.connector.errorcode','sqlite3','pdb',
      ],
      include_package_data=True,
      zip_safe=False)
# creando registro en pypi
#     python setup.py register
#
# crear el fichero
#     python setup.py sdist
#     - creara un fichero dist/pymetrick-0.1.tar.gz
# subir paquete 
#     python setup.py sdist upload
#
# todo lo anterior pero en un solo paso
#     python setup.py register sdist upload
#
# ver detalles de setup.py
#     python setup.py --help-commands
#
# python setup.py develop
#
# instalar con
#     pip install funniest

==> pymetrick-0.42.zip: pymetrick-0.42/setup.py <==
from setuptools import setup

def readme():
    with open('README.md') as f:
        return f.read()


setup(name='pymetrick',
      version='0.42',
      description='Lightweight web framework',
      long_description='lightweight web framework to ecommerce and management',
      classifiers=[
              'Development Status :: 5 - Production/Stable',
              'License :: OSI Approved :: GNU Lesser General Public License v2 or later (LGPLv2+)',
              'Programming Language :: Python :: 2',
              'Programming Language :: Python :: 2.7',
              'Programming Language :: Python :: 3',
              'Programming Language :: Python :: 3.4',
              'Programming Language :: Python :: 3.5',
              'Environment :: Web Environment',
              'Topic :: Internet :: WWW/HTTP :: WSGI :: Application',
            ],      
      url='',
      author='Fco. Javier Tamarit V',
      author_email='javtamvi@gmail.com',
      maintainer='Fco. Javier Tamarit V',
      maintainer_email='pymetrick@pymetrick.org',
      license='GNU/GPLv2',
      packages=['pymetrick'],
      install_requires=['pdb',
      ],
      include_package_data=True,
      zip_safe=False)

# creando registro en pypi
#     python setup.py register
#
# crear el fichero
#     python setup.py sdist
#     - creara un fichero dist/pymetrick-0.1.tar.gz
# subir paquete 
#     python setup.py sdist upload
#
# todo lo anterior pero en un solo paso
#     python setup.py register sdist upload
#
# ver detalles de setup.py
#     python setup.py --help-commands
#
# python setup.py develop
#
# instalar con
#     pip install funniest
#
# usuario : javtamvi
# password : BETACA96a
